package Task::Cabinet;

# ABSTRACT: Install all the CPAN modules needed by Cabinet

use v5.10.1;
use warnings;
use strict;

our $VERSION = '0.09'; # VERSION
our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY

1; # End of Task::Cabinet

__END__

=pod

=head1 NAME

Task::Cabinet - Install all the CPAN modules needed by Cabinet

=head1 VERSION

version 0.09

=head1 DESCRIPTION

This L<Task> module installs all the dependencies for the stable version of Cabinet.

=head1 SEE ALSO

L<Task>

=head1 AUTHOR

Anton Gerasimov <chim@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Anton Gerasimov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
